from tests.utils import service_ok

import pytest

from owslib.opensearch import OpenSearch

SERVICE_URL = 'https://finder.creodias.eu/resto/api/collections/Sentinel1/describe.xml'


@pytest.mark.online
# service testing is commented out given CREODIAS does not allow HEAD requests
# @pytest.mark.skipif(not service_ok(SERVICE_URL),
#                    reason='service is unreachable')
def test_opensearch_creodias():

    o = OpenSearch(SERVICE_URL)

    assert o.description.shortname == 'Sentinel-1'
    assert o.description.description == 'Sentinel-1 Collection'
    assert o.description.language == 'en'

    assert len(o.description.urls) == 2

    assert len(o.description.urls['application/json']['parameters']) > 0

    with pytest.raises(RuntimeError):
        _ = o.search('application/json', productType='invalid')

    with pytest.raises(RuntimeError):
        _ = o.search('application/json', foo='bar')

    results = o.search('application/json', productType='SLC')

    assert isinstance(results, dict)



from io import BytesIO

from tests.utils import service_ok

import pytest

from owslib.ogcapi.maps import Maps

SERVICE_URL = 'https://test.cubewerx.com/cubewerx/cubeserv/demo/ogcapi/EuroRegionalMap/'  # noqa


@pytest.mark.online
@pytest.mark.skipif(not service_ok(SERVICE_URL),
                    reason='service is unreachable')
def test_ogcapi_maps_pygeoapi():
    w = Maps(SERVICE_URL)

    assert w.url == SERVICE_URL
    assert w.url_query_string is None

    collections = w.collections()
    assert len(collections) > 0

    maps = w.maps()
    assert len(maps) > 0

    erm = w.collection('erm')
    assert erm['id'] == 'erm'
    assert erm['title'] == 'EuroRegionalMap'

    data = w.map('erm', width=1200, height=800, transparent=False)
    assert isinstance(data, BytesIO)




import pytest

from owslib.namespaces import Namespaces

def test_namespaces():
    ns = Namespaces()

    assert ns.get_namespace('csw') == 'http://www.opengis.net/cat/csw/2.0.2'

    x = ns.get_namespaces(['csw','gmd','fes'])
    assert x == {'csw': 'http://www.opengis.net/cat/csw/2.0.2', 'fes': 'http://www.opengis.net/fes/2.0', 'gmd': 'http://www.isotc211.org/2005/gmd'}

    ns.get_namespaces()

    assert ns.get_versioned_namespace('ows') == 'http://www.opengis.net/ows'

    assert ns.get_versioned_namespace('ows','1.0.0') == 'http://www.opengis.net/ows'

    assert ns.get_versioned_namespace('ows','1.1.0') ==  'http://www.opengis.net/ows/1.1'

    assert ns.get_versioned_namespace('ows','2.0.0') == 'http://www.opengis.net/ows/2.0'

    assert ns.get_namespaces('csw') == {'csw': 'http://www.opengis.net/cat/csw/2.0.2'}

    assert ns.get_namespace('csw') == 'http://www.opengis.net/cat/csw/2.0.2'

    assert ns.get_namespace('sa') == 'http://www.opengis.net/sampling/1.0'

    # 'om300' does not exist as a namespace, so the below will return nothing
    assert ns.get_namespace('om300') is None

    # CSW 3.1.1 doesn't exist, so the below will return nothing
    assert ns.get_versioned_namespace('csw','3.1.1') is None


    # Invalid Usage Tests

    with pytest.raises(TypeError):
        ns.get_namespace()

    with pytest.raises(TypeError):
        ns.get_versioned_namespace()



from tests.utils import service_ok

import pytest

from owslib.opensearch import OpenSearch

SERVICE_URL = 'https://demo.pycsw.org/cite/opensearch'


@pytest.mark.online
@pytest.mark.skipif(not service_ok(SERVICE_URL),
                    reason='service is unreachable')
def test_opensearch_creodias():

    o = OpenSearch(SERVICE_URL)

    assert o.description.shortname == 'pycsw OGC CITE d'
    assert o.description.longname == 'pycsw OGC CITE demo and Reference Implementation'

    assert len(o.description.urls) == 2

    results = o.search('application/atom+xml')

    assert isinstance(results, dict)



import pytest
from tests.utils import service_ok

from owslib.wms import WebMapService

SERVICE_URL = 'http://geoserv.weichand.de:8080/geoserver/wms'


@pytest.mark.online
@pytest.mark.skipif(not service_ok(SERVICE_URL),
                    reason="WMS service is unreachable")
def test_wms_getfeatureinfo_130():
    wms = WebMapService(SERVICE_URL, version='1.3.0')

    res1 = wms.getfeatureinfo(
        layers=['bvv:dgm50_epsg31468'], srs='EPSG:31468',
        bbox=(4500000, 5500000, 4500500, 5500500), size=(500, 500), format='image/jpeg',
        info_format="text/html", xy=(250, 250))
    html_string1 = res1.read().decode("utf-8")
    assert 'dgm5' in html_string1



# =============================================================================
# Copyright (c) 2023 Tom Kralidis
#
# Author: Tom Kralidis <tomkralidis@gmail.com>
#
# Contact email: tomkralidis@gmail.com
# =============================================================================

from pathlib import Path
import re
from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand
import sys


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)


def read(filename, encoding='utf-8'):
    """read file contents"""

    fullpath = Path(__file__).resolve().parent / filename

    with fullpath.open() as fh:
        contents = fh.read().strip()
    return contents


def get_package_version():
    """get version from top-level package init"""
    version_file = read('owslib/__init__.py')
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


readme = open('README.md').read()
reqs = [line.strip() for line in open('requirements.txt')]

MANIFEST = Path('MANIFEST')

if MANIFEST.exists():
    MANIFEST.unlink()


setup(
    name='OWSLib',
    version=get_package_version(),
    description='OGC Web Service utility library',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    license='BSD',
    keywords=' '.join([
        'gis',
        'ogc',
        'ogcapi',
        'ows',
        'opensearch',
        'iso',
        '19115',
        'fgdc',
        'dif',
        'ows',
        'wfs',
        'wms',
        'sos',
        'csw',
        'wps',
        'wcs',
        'capabilities',
        'metadata',
        'wmts'
    ]),
    author='Sean Gillies',
    author_email='sean.gillies@gmail.com',
    maintainer='Tom Kralidis',
    maintainer_email='tomkralidis@gmail.com',
    url='https://owslib.readthedocs.io',
    install_requires=reqs,
    python_requires='>=3.6',
    cmdclass={'test': PyTest},
    packages=find_packages(exclude=["docs", "etc", "examples", "tests"]),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Scientific/Engineering :: GIS',
    ]
)
